@@ -542,7 +542,7 @@ append_x1 <- function(string){
 #'
 #' Check factor levels before log-RSS calculation
 #'
-#' @param object `[glm, clogit]` \cr The model object from a fitted RSF/(i)SSF.
+#' @param model `[glm, clogit]` \cr The model object from a fitted RSF/(i)SSF.
 #' *I.e.*, it will be `object$model` when called within `log_rss()`.
 #' @param x1 `[data.frame]` \cr A `data.frame` representing the habitat values
 #' at location x_1. Must contain all fitted covariates as expected by
@@ -624,7 +624,7 @@ bootstrap_logrss <- function(object, ...){
 }
 
 #' @rdname bootstrap_logrss
-bootstrap_logrss.glm <- function(object, x1, x2, ci_level, n_boot, mle){
+bootstrap_logrss.glm <- function(object, x1, x2, ci_level, n_boot, mle, ...){
   #Perform the bootstrap
   arr <- replicate(n_boot, boot1.glm(object, x1, x2), simplify = "array")
   #Lower percentile
@@ -647,7 +647,7 @@ bootstrap_logrss.glm <- function(object, x1, x2, ci_level, n_boot, mle){
 }
 
 #' @rdname bootstrap_logrss
-bootstrap_logrss.fit_clogit <- function(object, x1, x2, ci_level, n_boot, mle){
+bootstrap_logrss.fit_clogit <- function(object, x1, x2, ci_level, n_boot, mle, ...){
   #Perform the bootstrap
   arr <- replicate(n_boot, boot1.fit_clogit(object, x1, x2), simplify = "array")
   #Lower percentile
