@@ -109,8 +109,6 @@ tac.track_xy <- function(x, ...) {
   # following abrahams 2017 and dray 2010
   x <- steps(x)
   ta <- x$ta_[-1]
-  1/nrow(x) * sum(diff(cos(ta))^2 + diff(sin(ta))^2)
-
-
+  1/nrow(x) * sum(diff(cos(ta))^2 + diff(sin(ta))^2, na.rm = TRUE)
 }
 
