@@ -152,7 +152,11 @@ step_lengths <- function(x, ...) {
 #' @rdname steps
 step_lengths.track_xy <- function(x, lonlat = FALSE, append_last = TRUE, ...) {
   if (lonlat) {
-    q <- c(as.vector(as_sf(x) |> sf::st_distance(which = "Great Circle") |> units::set_units("m")), NA)
+    x1 <- as_sf(x)
+    q <- c(as.vector(sf::st_distance(head(x1, -1), tail(x1, -1),
+                                     which = "Great Circle",
+                                     by_element = TRUE) |>
+                       units::set_units("m")), NA)
   } else {
     q <- sqrt(step_lengths_sq(x))
   }
