@@ -26,8 +26,8 @@ expect_true(is.na(get_crs(s1)))
 expect_true(is.na(get_crs(h1.1)))
 expect_true(is.na(get_crs(h1.2)))
 
-expect_true(is(get_crs(t2), "CRS"))
-expect_true(is(get_crs(s2), "CRS"))
+expect_true(is(get_crs(t2), "crs"))
+expect_true(is(get_crs(s2), "crs"))
 expect_true(is(get_crs(h2.1), "crs"))
 expect_true(is(get_crs(h2.2), "crs"))
 expect_true(is(get_crs(h2.3), "crs"))
